@@ -34,6 +34,8 @@
 #include "typedefs.h"
 
 #define SPECIAL_DIR(x) (! strcmp (x, "..") || ! strcmp (x, "."))
+#define errno_to_string() (gnome_vfs_result_to_string (gnome_vfs_result_from_errno ()))
+
 
 typedef struct _PathListData PathListData;
 
@@ -170,13 +172,12 @@ char *              remove_special_dirs_from_path (const char *path);
      
 GnomeVFSURI *       new_uri_from_path             (const char *path);
 
-GnomeVFSResult      resolve_all_symlinks_uri      (GnomeVFSURI *uri,
-						   GnomeVFSURI **result_uri);
+char *              new_path_from_uri             (GnomeVFSURI *uri);
 
 GnomeVFSResult      resolve_all_symlinks          (const char  *text_uri,
 						   char       **resolved_text_uri);
 
-#define errno_to_string() (gnome_vfs_result_to_string (gnome_vfs_result_from_errno ()))
+GnomeVFSFileSize    get_dest_free_space          (const char  *path);
 
 
 #endif /* FILE_UTILS_H */
