@@ -24,6 +24,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
+#include <libgnome/gnome-help.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include "gthumb-window.h"
 #include "gtk-utils.h"
@@ -317,6 +318,39 @@ update_list_cb (GtkWidget  *widget,
 }
 
 
+/* called when the "help" button is clicked. */
+static void
+help_cb (GtkWidget  *widget, 
+	 DialogData *data)
+{
+	GError *err;
+
+	err = NULL;  
+	gnome_help_display ("gthumb", "gthumb-rename-series", &err);
+	
+	if (err != NULL) {
+		GtkWidget *dialog;
+		
+		dialog = gtk_message_dialog_new (GTK_WINDOW (data->dialog),
+						 0,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("Could not display help: %s"),
+						 err->message);
+		
+		g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+		
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		
+		gtk_widget_show (dialog);
+		
+		g_error_free (err);
+	}
+}
+
+
 
 void
 dlg_rename_series (GThumbWindow *window)
@@ -324,6 +358,7 @@ dlg_rename_series (GThumbWindow *window)
 	DialogData        *data;
 	GtkWidget         *btn_ok;
 	GtkWidget         *btn_cancel;
+	GtkWidget         *help_button;
 	GList             *list;
 	GtkCellRenderer   *renderer;
 	GtkTreeViewColumn *column;
@@ -358,6 +393,7 @@ dlg_rename_series (GThumbWindow *window)
 
         btn_ok = glade_xml_get_widget (data->gui, "rs_ok_button");
         btn_cancel = glade_xml_get_widget (data->gui, "rs_cancel_button");
+	help_button = glade_xml_get_widget (data->gui, "rs_help_button");
 
 	/* Set widgets data. */
 
@@ -412,6 +448,10 @@ dlg_rename_series (GThumbWindow *window)
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
 				  G_OBJECT (data->dialog));
+	g_signal_connect (G_OBJECT (help_button), 
+			  "clicked",
+			  G_CALLBACK (help_cb),
+			  data);
 
 	g_signal_connect (G_OBJECT (data->rs_template_entry), 
 			  "changed",
